@@ -7,20 +7,29 @@ import sys
 import pip
 
 
-def get_target_dir():
+def get_pypackages_lib_path(script_path=None):
     """returns path in compliance with PEP 582
     https://www.python.org/dev/peps/pep-0582/
     """
+    if script_path:
+        # use __pypackages__ relative to the script being run
+        pypackages = os.path.join(os.path.dirname(script_path), "__pypackages__")
+        print(pypackages)
+    else:
+        pypackages = "__pypackages__"
+
     return os.path.join(
-        "__pypackages__",
+        pypackages,
         str(sys.version_info.major) + "." + str(sys.version_info.minor),
         "lib",
     )
 
 
-def get_env():
+def get_env(script_path=None):
     env = dict(os.environ)
-    env["PYTHONPATH"] = ".:" + get_target_dir() + ":" + env.get("PYTHONPATH", "")
+    env["PYTHONPATH"] = (
+        ".:" + get_pypackages_lib_path(script_path) + ":" + env.get("PYTHONPATH", "")
+    )
     return env
 
 
@@ -28,16 +37,24 @@ def null_handler(signum, frame):
     pass
 
 
+def get_script_path():
+    for arg in sys.argv[1:]:
+        if not arg.startswith("-"):
+            return os.path.abspath(arg)
+    return None
+
+
 def pythonloc():
     args = [sys.executable] + sys.argv[1:]
-    os.execve(sys.executable, args, get_env())
+    script_path = get_script_path()
+    os.execve(sys.executable, args, get_env(script_path))
 
 
 def _get_pip_target_args(pip_args):
     if "install" in pip_args:
         if "--target" not in pip_args:
             # use target dir if installing
-            target = ["--target", get_target_dir()]
+            target = ["--target", get_pypackages_lib_path()]
         if (
             pip.__version__.startswith("9.") or pip.__version__.startswith("10.")
         ) and "--system" not in pip_args:
